# Argos-NetBox
NetBox plugin for documenting network services in NetBox for the purposes of SSoT based deployment. Can be used in conjunction with [argos-nac](https://pypi.org/project/argos-nac/) for automated, SSoT based service deployment.

## Currently supported services
### MPLS L3 VPN:
- BGP (Full mesh topology only)
- LDP (Manual + automatic ranges)
- VRF
